# eadb
**eadb=easy adb**</br>
封装常用的adb命令，提高使用效率，仅限：macOS、Linux使用

## 背景
在使用adb命令时，获取设备名、设备版本号、截屏等功能，输入的终端命令比较长，效率比较低，所以才有了这个小工具的诞生。

## 安装环境
 1. 搭建 Java 开发环境
 2. 搭建 Android-SDK 开发环境
 3. 安装 Python 3 环境，推荐使用3.7

## 使用方法
### 1. 从pypi下载安装即可

 ```
pip install eadb        # 安装
pip install -U eabb     # 更新版本
 ```
